        IF (SLIP_INC)
        ELSE
SLIP_INC        SET     1
;**
;**     $Filename: slip.inc
;**     $Release: 1
;**     $Revision: 1
;**     $Date: 10/11/1998
;**
;**     
;**
;**     Coded by Joachim Elen
;**

;----------------------------------------------------------
;
;       SLIP Specific MACRO definition
;
;----------------------------------------------------------

JPB     MACRO   pbit,label
        jnb     pbit,label
        ENDM

JNPB    MACRO   pbit,label
        jb      pbit,label
        ENDM

SETP    MACRO   pbit
        clr     pbit
        ENDM

CLRP    MACRO   pbit
        setb    pbit
        ENDM

CPLP    MACRO   pbit
        cpl     pbit
        ENDM

PBMOV   MACRO   dpbit,spbit
        mov     C,spbit
        mov     dpbit,C
        ENDM


;----------------------------------------------------------
;
;       Constants
;
;----------------------------------------------------------

;------ SLIP Frame Escape sequences

FEND            EQU 0C0h        ;Frame END
FESC            EQU 0DBh        ;Frame ESCape
TFEND           EQU 0DCh        ;Transpose Frame END
TFESC           EQU 0DDh        ;Transpose Frame ESCape


;------ Modem result codes

RC_OK           EQU 0
RC_CONNECT      EQU 1
RC_RING         EQU 2
RC_NOCARRIER    EQU 3
RC_ERROR        EQU 4
RC_C1200        EQU 5
RC_NOTONE       EQU 6
RC_BUSY         EQU 7
RC_NOANSWER     EQU 8
RC_C2400        EQU 10
RC_C4800        EQU 11
RC_C9600        EQU 12
RC_C14400       EQU 13
RC_C19200       EQU 19
RC_C21600       EQU 21
RC_C24000       EQU 24
RC_C26400       EQU 26
RC_C28800       EQU 28
RC_SYSTEMERROR  EQU 30
RC_VOID         EQU 255


;------ LCD display constants

LCD_R0  equ     00h         ;offset row 1
LCD_R1  equ     28h         ;offset row 2
LCD_R2  equ     14h         ;offset row 3
LCD_R3  equ     3Ch         ;offset row 4

;----------------------------------------------------------
;
;       External DATA memory partitioning
;
;----------------------------------------------------------
       XSTRUCTURE 0000h
        XSTRUCT AtBuffer,ATB_SIZEOF,00100h      ;AT command buffer
        XSTRUCT FrameBuf,FRB_SIZEOF,00100h      ;incoming frame filter
        XSTRUCT HistBuffer,HST_SIZEOF,00100h    ;AT history buffer
        XSTRUCT CallBuffer,CALL_SIZEOF,00100h   ;Callsign buffer

;global I/O
        XSTRUCT RxBuffer,RXB_SIZEOF,01000h      ;RX buffer
        XSTRUCT TxBuffer,TXB_SIZEOF,07000h      ;TX buffer

;serial I/O
        XSTRUCT LRBuffer,LRB_SIZEOF,01000h      ;read lsc buffer
        XSTRUCT LTBuffer,LTB_SIZEOF,01000h      ;write lsc buffer

        XSTRUCT LCDBuf,LCD_SIZEOF,00100h        ;LCD display buffer

HostCall       EQU     FrameBuf+0
ServCall       EQU     FrameBuf+16
FrameHeader    EQU     FrameBuf+64

;----------------------------------------------------------
;
;       Port pin assignments
;
;----------------------------------------------------------

;------ Baycom modem status

DCD             BIT P4.6
PTT             BIT P4.7

;------ TNC status LEDs

LED_PUTGSC      BIT P4.0
LED_GETLSC      BIT P4.1
LED_GETGSC      BIT P4.2
LED_PUTLSC      BIT P4.3
LED_REJECT      BIT P4.4
LED_VALID       BIT P4.4
LED_ONLINE      BIT P4.5

;----------------------------------------------------------
;
;       On-Chip flag assignments
;
;----------------------------------------------------------

        BITSTRUCT 000h



;--- SLIP flags

        bitdef  SF_GETTYP       ;reading KISS-frame from host
        bitdef  SF_CFRAME       ;command-frame
        bitdef  SF_DFRAME       ;data-frame
        bitdef  SF_FESC         ;Frame-ESCape mode is enabled
        bitdef  SF_CFPARAM      ;Next byte is command frame parameter


;--- TX flags

        bitdef  TX_BUSY         ;TX/GSC busy
        bitdef  TX_TAIL         ;TXTail active


;--- AT CLI flags

        bitdef  AT_ECHO         ;command echo enabled
        bitdef  AT_RESULTCODES  ;resultcodes enabled
        bitdef  AT_VERBOSE      ;verbose result codes
        bitdef  AT_NOERRORS     ;ignore error messages
        bitdef  AT_GLBUFFERING  ;AT chars are being buffered
        bitdef  AT_GLGOTA       ;'A' char for AT or A/ is received
        bitdef  AT_GLGOTCR      ;CR,LF processing activated
        bitdef  AT_DIGIS        ;when set digis must be repeated to
                                ;accept the frame

;--- Data link flags

        bitdef  DL_CONNECT
        bitdef  DL_FLOWOFF

;--- lsc flags

        bitdef  lt_done

;--- misc flags

        bitdef  LCD_ENABLED
        bitdef  LED_ALT4



;----------------------------------------------------------
;
;       On-Chip byte definitions
;
;----------------------------------------------------------


        STRUCTURE 28h           ;new data structure


;---- registers for frame escape check

        ubyte   at_glesccnt     ;number of escape characters received
        ubyte   at_glescstr     ;type of escape string 0=none,1=+++,2=ATH
        ubyte   at_idletimer    ;if over 16, AT_IDLE is set.

;---- command line interpreter vars

        ubyte   at_index        ;offset of at data
        ubyte   at_indexindex   ;offset counted from index
        ubyte   at_item         ;current entry in at command list
        ubyte   at_itemindex    ;offset in string of current entry
        uword   at_history      ;at command history log

;--- SLIP Protocol variables

        ubyte   slip_randomize  ;persistance randomizer
        ubyte   slip_hardware
        ubyte   slip_txdelay
        ubyte   slip_persist
        ubyte   slip_slottime
        ubyte   slip_txtail
        ;ubyte   slip_fullduplex

;---- offline modem regs

        ubyte   at_cspeed       ;connection speed notation
        ubyte   at_s0           ;auto answer ring number
        ubyte   at_s1           ;ring count
        ubyte   at_s2           ;escape code char (+)
        ubyte   at_s3           ;carriage return char (CR)
        ubyte   at_s4           ;line feed char (LF)
        ubyte   at_s5           ;backspace char
        ubyte   at_s6           ;wait time before blind dial
        ubyte   at_s7           ;wait time for carrier
        ubyte   at_s8           ;pause time for carrier
        ubyte   at_s9           ;carrier detect response time
        ubyte   at_s10          ;carrier lost to hang up delay

;--- physical layer variables

        ubyte   ph_randomize    ;persistance randomizer
        ubyte   ph_command
        ubyte   ph_txdelay
        ubyte   ph_persist
        ubyte   ph_slottime
        ubyte   ph_txtail
        ubyte   ph_fullduplex
        ubyte   ph_valid

        uword   ph_legalframes
        uword   ph_errorframes
        uword   ph_validframes
        uword   ph_totalframes

;--- online rx variables

        aptr    rx_writeframe   ;GetGSC framepointer
        aptr    rx_writedata    ;GetGSC datapointer
        aptr    rx_readframe    ;PutLSC framepointer
        aptr    rx_readdata     ;PutLSC datapointer
        uword   rx_framelen     ;actual RX framelength
        uword   rx_allocated    ;RXBuffer allocated memory
        ubyte   rx_framecount   ;framecounter

;--- online tc variables

        aptr    tx_writeframe   ;GetLSC framepointer
        aptr    tx_writedata    ;GetLSC datapointer
        aptr    tx_readframe    ;PutGSC framepointer
        aptr    tx_readdata     ;PutGSC datapointer
        uword   tx_framelen     ;actual TX framelength
        uword   tx_allocated    ;TXBuffer allocated memory
        ubyte   tx_framecount   ;framecounter
        uword   tx_dmaframelen  ;actual TX framelength for DMA

;--- lcd display

        ubyte   lcd_offset

;--- local io device
        aptr    ltw_data        ;tx lsc datawrite pointer
        aptr    ltr_data        ;tx lsc dataread pointer
        uword   lt_alloc        ;tx lsc allocated bytes

        aptr    lrw_data        ;rx lsc datawrite pointer
        aptr    lrr_data        ;rx lsc dataread pointer
        uword   lr_alloc        ;rx lsc allocated bytes

;--- frame header
        
        ubyte   fh_sizeof
        ubyte   fh_control
        ubyte   fh_pid



        ENDIF   ; SLIP_INC





















